@@ -23,7 +23,6 @@ import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
 
-import org.dmg.pmml.DataDictionary;
 import org.dmg.pmml.DataField;
 import org.dmg.pmml.FieldName;
 import org.dmg.pmml.MiningField;
@@ -32,11 +31,16 @@ import org.dmg.pmml.Model;
 import org.dmg.pmml.ModelStats;
 import org.dmg.pmml.PMML;
 import org.dmg.pmml.UnivariateStats;
-import org.jpmml.converter.visitors.CleanerBattery;
+import org.dmg.pmml.Visitor;
+import org.jpmml.converter.mining.MiningModelUtil;
+import org.jpmml.converter.visitors.AttributeCleaner;
+import org.jpmml.converter.visitors.ModelCleanerBattery;
 import org.jpmml.model.VisitorBattery;
 
 public class ModelEncoder extends PMMLEncoder {
 
+	private List<Model> transformers = new ArrayList<>();
+
 	private Map<FieldName, List<Decorator>> decorators = new LinkedHashMap<>();
 
 	private Map<FieldName, UnivariateStats> univariateStats = new LinkedHashMap<>();
@@ -45,61 +49,75 @@ public class ModelEncoder extends PMMLEncoder {
 	public PMML encodePMML(Model model){
 		PMML pmml = encodePMML();
 
-		pmml.addModels(model);
+		List<Model> transformers = getTransformers();
+		if(transformers.size() > 0){
+			List<Model> models = new ArrayList<>(transformers);
 
-		VisitorBattery visitorBattery = new CleanerBattery();
-		if(visitorBattery.size() > 0){
-			visitorBattery.applyTo(pmml);
-		}
-
-		MiningSchema miningSchema = model.getMiningSchema();
-
-		List<MiningField> miningFields = miningSchema.getMiningFields();
-		for(MiningField miningField : miningFields){
-			FieldName name = miningField.getName();
-
-			List<Decorator> decorators = getDecorators(name);
-			if(decorators == null){
-				continue;
+			if(model != null){
+				models.add(model);
 			}
 
-			DataField dataField = getDataField(name);
-			if(dataField == null){
-				throw new IllegalArgumentException();
+			model = MiningModelUtil.createModelChain(models);
+		} // End if
+
+		if(model != null){
+			pmml.addModels(model);
+
+			VisitorBattery modelCleanerBattery = new ModelCleanerBattery();
+			if(modelCleanerBattery.size() > 0){
+				modelCleanerBattery.applyTo(pmml);
 			}
 
-			for(Decorator decorator : decorators){
-				decorator.decorate(dataField, miningField);
+			MiningSchema miningSchema = model.getMiningSchema();
+
+			List<MiningField> miningFields = miningSchema.getMiningFields();
+			for(MiningField miningField : miningFields){
+				FieldName name = miningField.getName();
+
+				DataField dataField = getDataField(name);
+				if(dataField == null){
+					throw new IllegalArgumentException("Field " + name.getValue() + " is not referentiable");
+				}
+
+				List<Decorator> decorators = getDecorators(name);
+				if(decorators != null){
+
+					for(Decorator decorator : decorators){
+						decorator.decorate(miningField);
+					}
+				}
+
+				UnivariateStats univariateStats = getUnivariateStats(name);
+				if(univariateStats != null){
+					ModelStats modelStats = ModelUtil.ensureModelStats(model);
+
+					modelStats.addUnivariateStats(univariateStats);
+				}
 			}
 		}
 
-		DataDictionary dataDictionary = pmml.getDataDictionary();
-
-		List<DataField> dataFields = dataDictionary.getDataFields();
-		for(DataField dataField : dataFields){
-			UnivariateStats univariateStats = getUnivariateStats(dataField.getName());
-
-			if(univariateStats == null){
-				continue;
-			}
-
-			ModelStats modelStats = model.getModelStats();
-			if(modelStats == null){
-				modelStats = new ModelStats();
-
-				model.setModelStats(modelStats);
-			}
-
-			modelStats.addUnivariateStats(univariateStats);
-		}
+		Visitor pmmlCleaner = new AttributeCleaner();
+		pmmlCleaner.applyTo(pmml);
 
 		return pmml;
 	}
 
+	public List<Model> getTransformers(){
+		return this.transformers;
+	}
+
+	public void addTransformer(Model transformer){
+		this.transformers.add(transformer);
+	}
+
 	public List<Decorator> getDecorators(FieldName name){
 		return this.decorators.get(name);
 	}
 
+	public void addDecorator(DataField dataField, Decorator decorator){
+		addDecorator(dataField.getName(), decorator);
+	}
+
 	public void addDecorator(FieldName name, Decorator decorator){
 		List<Decorator> decorators = this.decorators.get(name);
 
